ytree\.tree\_farm\.ancestry\_checker\.add\_ancestry\_checker
============================================================

.. currentmodule:: ytree.tree_farm.ancestry_checker

.. autofunction:: add_ancestry_checker